using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Runtime.InteropServices; //requirement class

namespace CShare.Net2005
{
    public partial class MainForm : Form
    {
        //1.1 TIFF compression tag definitions.
        //==========================================================================================
        const int AP_TIFF_COMPRESSION_NONE = 0;  //No compression.
        const int AP_TIFF_COMPRESSION_LZW = 1;  //1,4,8,24bits(default 4,8,24bits)
        const int AP_TIFF_COMPRESSION_JPEG = 2;  //Grayscale 8bits,24bits
        const int AP_TIFF_COMPRESSION_PACKBITS = 3;  //4,8,24bits
        const int AP_TIFF_COMPRESSION_CCITTG4 = 4;  //1bit(default 1bit)
        const int AP_TIFF_COMPRESSION_CCITTG3 = 5;  //1bit
        const int AP_TIFF_COMPRESSION_RLE = 6;  //1bit
        //==========================================================================================

        //1.2 Image type definitions
        //=======================================================================================
        const int AP_IMAGE_BMP = 1;   //BMP
        const int AP_IMAGE_EMF = 2;   //EMF
        const int AP_IMAGE_WMF = 3;   //WMF
        const int AP_IMAGE_JPG = 4;   //JPG
        const int AP_IMAGE_PNG = 5;   //PNG
        const int AP_IMAGE_GIF = 6;   //GIF
        const int AP_IMAGE_TIF = 7;   //TIF
        const int AP_IMAGE_PCX = 8;   //PCX

        const int AP_IMAGE_JPEG = 4;   //JPEG
        const int AP_IMAGE_TIFF = 7;   //TIFF
        //=======================================================================================

        //1.3 Return code definitions.
        //==========================================================================================
        const int RTN_OK = 1;           //Successful operation.
        const int ERR_UNKNOWN = -99;    //Unknown system error.

        const int ERR_OVER_MAXTHREADS = -1;  //Over the limit amount of threads
        const int ERR_FILE_UNEXIST = -2;  //Source PDF file unexist.
        const int ERR_FILE_DAMAGED = -3;  //Source PDF file is damaged.
        const int ERR_FILE_RESTRICTED = -4;  //Source PDF file is restricted.
        //==========================================================================================

        //1.4 Windows API definitions.
        //==============================================================================================================
        [DllImport("kernel32.dll")]
        public static extern int GetTickCount();
        [DllImport("kernel32.dll")]
        public static extern void CopyMemory(Byte[] dest, int Source, Int32 length);

        const int TRUE = 1;
        const int FALSE = 0;
        //==============================================================================================================

        //Defining an AP Pdf2Image ActiveX Control ojbect.
        AP_PDF2IMAGE.AxPdf2Image m_AxPdf2Image;

        public MainForm()
        {
            InitializeComponent();

            //Initialzing AP Pdf2Image ActiveX Control object.
            m_AxPdf2Image = new AP_PDF2IMAGE.AxPdf2ImageClass();
        }

        //Demo1 - To convert all pages of the pdf document.
        private void btnDemo1_Click(object sender, EventArgs e)
        {
            String sFileName = "sample.pdf";

            int iStartTick, iEndTick;
            iStartTick = GetTickCount();

            //Open pdf document and creating a converter.
            int nHandle = m_AxPdf2Image.apOpen(sFileName, "", "");
            switch (nHandle)
            {
                case ERR_OVER_MAXTHREADS: { MessageBox.Show("Over the limit amount of threads,please waiting!"); return; };
                case ERR_FILE_UNEXIST: { MessageBox.Show("Source pdf file unexist!"); return; };
                case ERR_FILE_DAMAGED: { MessageBox.Show("Source pdf file damaged!"); return; };
                case ERR_FILE_RESTRICTED: { MessageBox.Show("Source pdf file restricted!"); return; };
            }

            //Setting proerties.
            m_AxPdf2Image.sOutDirectory = "demo1";
            m_AxPdf2Image.iImageType = AP_IMAGE_PNG;
            m_AxPdf2Image.iXDPI = 130;
            m_AxPdf2Image.iYDPI = 130;

            //To convert all pages of the pdf document.
            long iPageCount = m_AxPdf2Image.apGetPageCount(nHandle);
            for (int iPageNo = 1; iPageNo <= iPageCount; iPageNo++)
            {
                m_AxPdf2Image.apConvertPage(nHandle, iPageNo);

                //Setting conversion's progress.
                m_ProgressBar.Value = (int)((iPageNo * 1.0) / iPageCount * 100);
            }

            //Close pdf document and destory the converter.
            m_AxPdf2Image.apClose(nHandle);

            //To count conversion's time(ms).
            iEndTick = GetTickCount();
            MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
        }

        //demo2 - To convert appointed pdf pages of the pdf document to memory stream.
        private void btnDemo2_Click(object sender, EventArgs e)
        {
            String sFileName = "sample.pdf";
            int iStartTick, iEndTick;
            int[] m_Pages = { 1, 3, 6, 8, 9, 11 };

            iStartTick = GetTickCount();
            //Open pdf document and creating a converter.
            int nHandle = m_AxPdf2Image.apOpen(sFileName, "", "");
            switch (nHandle)
            {
                case ERR_OVER_MAXTHREADS: { MessageBox.Show("Over the limit amount of threads,please waiting!"); return; };
                case ERR_FILE_UNEXIST: { MessageBox.Show("Source pdf file unexist!"); return; };
                case ERR_FILE_DAMAGED: { MessageBox.Show("Source pdf file damaged!"); return; };
                case ERR_FILE_RESTRICTED: { MessageBox.Show("Source pdf file restricted!"); return; };
            }

            //Setting proerties.
            m_AxPdf2Image.iImageType = AP_IMAGE_JPEG;
            m_AxPdf2Image.iQuality = 60;
            m_AxPdf2Image.iXDPI = 110;
            m_AxPdf2Image.iYDPI = 110;
            m_AxPdf2Image.iXDimensions = 995;
            m_AxPdf2Image.iYDimensions = 1287;

            //To convert the appointed pages of the pdf document.
            System.IO.Directory.CreateDirectory("demo2");
            long iPageCount = m_Pages.Length;
            for (int iPos = 0; iPos <= iPageCount - 1; iPos++)
            {
                //You can save image stream to database, to file, or to others, etc.
                m_AxPdf2Image.apConvertPageToStream(nHandle, m_Pages[iPos]);

                //Here,it saves the stream to file.
                if (m_AxPdf2Image.iStreamSize > 0)
                {
                    //Here,it saves the memory image stream to bytes buffer
                    byte[] bBuffer = new byte[m_AxPdf2Image.iStreamSize];
                    CopyMemory(bBuffer, m_AxPdf2Image.iStreamHandle, m_AxPdf2Image.iStreamSize);

                    //Here,it saves the bytes buffer to file.
                    string sImgFile = "./demo2/myimg_" + m_Pages[iPos] + ".jpg";
                    System.IO.FileStream fileStream = new System.IO.FileStream(sImgFile, System.IO.FileMode.OpenOrCreate, System.IO.FileAccess.Write);
                    fileStream.Write(bBuffer, 0, m_AxPdf2Image.iStreamSize);
                    fileStream.Close();
                }

                //Setting conversion's progress.
                m_ProgressBar.Value = (int)((iPos + 1) * 1.0 / m_Pages.Length * 100);
            }

            //Close pdf document and destory the converter.
            m_AxPdf2Image.apClose(nHandle);

            //To count conversion's time(ms).
            iEndTick = GetTickCount();
            MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
        }
    }
}